require 'spec_helper'
require 'birdseed'

describe Birdseed do
  let(:response) { double('Response') }

  it "should send delivery" do
    Birdseed.api_key = "test_api_key"
    stub_request(:post, "#{Birdseed.fatbird_host}/deliveries").
         with(:body => JSON.generate({template_id: 'test_template', recipient: {address: 'test@example.com'}}),
              :headers => {'Accept'=>'application/json', 'Authorization'=>'api_key test_api_key', 'Content-Type'=>'application/json'}).
         to_return(:status => 200, :body => "{\"url\":\"https://fatbird.edmodo.com/deliveries/10956571\",\"campaign_id\":\"fatbird-test\",\"template_id\":\"fatbird-test\",\"recipient\":{\"address\":\"jerry@edmodo.com\",\"name\":\"Jerry Luk\"},\"sender\":{\"address\":\"notifications@edmodo.com\",\"name\":\"Edmodo\",\"reply_to\":\"announcements@edmodo.com\"},\"locale\":\"en-US\",\"id\":10956571,\"send_at\":null,\"sent_at\":null,\"status\":\"created\",\"data\":null,\"created_at\":\"2015-04-21T22:36:28.786Z\",\"updated_at\":\"2015-04-21T22:36:28.786Z\"}", :headers => {})
    result = Birdseed.deliver(template_id: 'test_template', recipient: {address: 'test@example.com'})
    expect(result.id).to eq(10956571)
  end

  it "should send delivery item" do
    Birdseed.api_key = "test_api_key"
    stub_request(:post, "#{Birdseed.fatbird_host}/delivery_items").
         with(:body => JSON.generate({campaign_id: 'fatbird-test', scope: "1", recipient: {address: 'test@example.com'}}),
              :headers => {'Accept'=>'application/json', 'Authorization'=>'api_key test_api_key', 'Content-Type'=>'application/json'}).
         to_return(:status => 200, :body => "{\"url\":\"https://fatbird.edmodo.com/delivery_items/10956571\",\"campaign_id\":\"fatbird-test\",\"scope\":\"1\",\"recipient\":{\"address\":\"jerry@edmodo.com\",\"name\":\"Jerry Luk\"},\"locale\":\"en-US\",\"id\":10956571,\"send_at\":null,\"sent_at\":null,\"data\":null,\"created_at\":\"2015-04-21T22:36:28.786Z\",\"updated_at\":\"2015-04-21T22:36:28.786Z\"}", :headers => {})
    result = Birdseed.deliver_item(campaign_id: 'fatbird-test', scope: "1", recipient: {address: 'test@example.com'})
    expect(result.id).to eq(10956571)
  end

  it "should get sample data" do
    Birdseed.api_key = "test_api_key"
    stub_request(:get, "#{Birdseed.fatbird_host}/campaigns/test/sample_data?dafault_value=DEFAULT_VALUE").
         with(:headers => {'Accept'=>'application/json', 'Authorization'=>'api_key test_api_key', 'Content-Type'=>'application/json'}).
         to_return(:status => 200, :body => JSON.generate("test" => "VALUE"), :headers => {})
    result = Birdseed.sample_data('test', default_value: 'DEFAULT_VALUE')
    expect(result).to eq({"test" => "VALUE"})
  end
end
